@@ -22,7 +22,7 @@
 ***********************************************************************/
 
 #include "env.h"
-#include "glpapi.h"
+#include "prob.h"
 #include "triang.h"
 
 /***********************************************************************
